@@ -14,10 +14,51 @@
 
 import os
 
-from tempest import config
+from six.moves import configparser
 from tempest_lib.cli import base
 
-CONF = config.CONF
+
+CLI_DIR = os.environ.get(
+    'OS_MISTRALCLIENT_EXEC_DIR',
+    os.path.join(os.path.abspath('.'), '.tox/functional/bin')
+)
+_CREDS_FILE = 'functional_creds.conf'
+
+
+def credentials(group='admin'):
+    """Retrieves credentials to run functional tests.
+
+    Credentials are either read from the environment or from a config file
+    ('functional_creds.conf'). Environment variables override those from the
+    config file.
+
+    The 'functional_creds.conf' file is the clean and new way to use (by
+    default tox 2.0 does not pass environment variables).
+    """
+    if group == 'admin':
+        username = os.environ.get('OS_USERNAME')
+        password = os.environ.get('OS_PASSWORD')
+        tenant_name = os.environ.get('OS_TENANT_NAME')
+    else:
+        username = os.environ.get('OS_ALT_USERNAME')
+        password = os.environ.get('OS_ALT_PASSWORD')
+        tenant_name = os.environ.get('OS_ALT_TENANT_NAME')
+
+    auth_url = os.environ.get('OS_AUTH_URL')
+
+    config = configparser.RawConfigParser()
+    if config.read(_CREDS_FILE):
+        username = username or config.get(group, 'user')
+        password = password or config.get(group, 'pass')
+        tenant_name = tenant_name or config.get(group, 'tenant')
+        auth_url = auth_url or config.get('auth', 'uri')
+
+    return {
+        'username': username,
+        'password': password,
+        'tenant_name': tenant_name,
+        'auth_url': auth_url
+    }
 
 
 class MistralCLIAuth(base.ClientTestBase):
@@ -25,12 +66,15 @@ class MistralCLIAuth(base.ClientTestBase):
     _mistral_url = None
 
     def _get_admin_clients(self):
+        creds = credentials()
+
         clients = base.CLIClient(
-            username=CONF.identity.admin_username,
-            password=CONF.identity.admin_password,
-            tenant_name=CONF.identity.admin_tenant_name,
-            uri=CONF.identity.uri,
-            cli_dir='/usr/local/bin')
+            username=creds['username'],
+            password=creds['password'],
+            tenant_name=creds['tenant_name'],
+            uri=creds['auth_url'],
+            cli_dir=CLI_DIR
+        )
 
         return clients
 
@@ -56,12 +100,15 @@ class MistralCLIAltAuth(base.ClientTestBase):
     _mistral_url = None
 
     def _get_alt_clients(self):
+        creds = credentials('demo')
+
         clients = base.CLIClient(
-            username=CONF.identity.alt_username,
-            password=CONF.identity.alt_password,
-            tenant_name=CONF.identity.alt_tenant_name,
-            uri=CONF.identity.uri,
-            cli_dir='/usr/local/bin')
+            username=creds['username'],
+            password=creds['password'],
+            tenant_name=creds['tenant_name'],
+            uri=creds['auth_url'],
+            cli_dir=CLI_DIR
+        )
 
         return clients
 
